@@ -93,5 +93,12 @@ sub has_enclosure {
     scalar @{$self->{enclosures}} > 0;
 }
 
+sub digest {
+    my $self = shift;
+    my $data = $self->title . ($self->body || '');
+    Encode::_utf8_off($data);
+    Digest::MD5::md5_hex($data);
+}
+
 1;
 
